@@ -1,4 +1,4 @@
-// $Id: antidos.h,v 1.3 2003/05/26 21:49:22 ensc Exp $    --*- c++ -*--
+// $Id: antidos.h,v 1.4 2004/06/15 11:56:46 ensc Exp $    --*- c++ -*--
 
 // Copyright (C) 2002,2003 Enrico Scholz <enrico.scholz@informatik.tu-chemnitz.de>
 //  
@@ -19,7 +19,7 @@
 #ifndef H_IPSENTINEL_ANTIDOS_H
 #define H_IPSENTINEL_ANTIDOS_H
 
-#include "vector.h"
+#include "ensc_vector/vector.h"
 
 #include <stdbool.h>
 #include <netinet/in.h>
